@@ -1,36 +1,34 @@
 """
-A Python module for navigating and mapping Solar System observations.
+A Python module for visualising, navigating and mapping Solar System observations.
 
-.. warning::
-
-    This code is in active development, and may break/change/not work at all.
-
-    Bugs can be reported at https://github.com/ortk95/planetmapper/issues/new
+..
+    See https://planetmapper.readthedocs.io for full documentation.
 
 The core logic of this code is based on conversion between different coordinate systems
 of interest. The `xy` and `radec` coordinate systems define positions from the point of
 view of the observer while the `lonlat` coordinate system defines locations on the
-surface of the target body.
+surface of the target body:
 
-`xy` image pixel coordinates. These coordinates count the number of pixels in an
+`xy`: image pixel coordinates. These coordinates count the number of pixels in an
 observed image with the bottom left pixel defined as `(0,0)`, and the `x` and `y`
 coordinates defined as normal. Integer coordinates represent the middle of the
 corresponding pixel, so `(0, 3)` covers `x` values from -0.5 to 0.5 and `y` values from
 2.5 to 3.5.
 
-`radec` observer frame RA/Dec sky coordinates. These are the right ascension and
+`radec`: observer frame RA/Dec sky coordinates. These are the right ascension and
 declination which define the position in the sky of a point from the point of view of
 the observer. These coordinates are expressed in degrees. See 
-https://en.wikipedia.org/wiki/Equatorial_coordinate_system for more.
+`Wikipedia <https://en.wikipedia.org/wiki/Equatorial_coordinate_system>`__ for more 
+details.
 
-`lonlat` planetographic coordinates on target body. These are the planetographic 
+`lonlat`: planetographic coordinates on target body. These are the planetographic 
 longitude and latitude coordinates of a point on the surface of the target body. These 
 coordinates are expressed in degrees. See 
-https://en.wikipedia.org/wiki/Planetary_coordinate_system and 
-https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/recpgr_c.html#Particulars for
-more.
+`Wikipedia <https://en.wikipedia.org/wiki/Planetary_coordinate_system>`__ and 
+`the SPICE documentation <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/recpgr_c.html#Particulars>`__
+for more details.
 
-`km` defines the distance in the image plane from the centre of the target body in km
+`km`: defines the distance in the image plane from the centre of the target body in km
 with the target's north pole pointing up. This coordinate system is similar to the
 `radec` and `xy` coordinate systems, but has the image zoomed so that the planet's 
 radius is fixed and rotated so that the north pole points up. It can therefore be useful
@@ -64,10 +62,17 @@ interface with SPICE:
 
 
 This code makes extensive use of the the `spiceypy` package which provides a Python
-wrapper around NASA's `cspice` toolkit. For more details, see:
+wrapper around NASA's `cspice` toolkit. See the 
+`spiceypy documentation <https://spiceypy.readthedocs.io/en/main/documentation.html>`__
+and the 
+`SPICE documentation <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/>`__
+for more information.
 
-- https://spiceypy.readthedocs.io/en/main/documentation.html
-- https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/
+.. warning::
+
+    This code is in active development, so may contain bugs! Any issues, bugs and 
+    suggestions can be 
+    `reported on GitHub <https://github.com/ortk95/planetmapper/issues/new>`__.
 """
 from .common import __version__, __author__, __url__
 from .base import SpiceBase
@@ -88,6 +93,7 @@ __all__ = [
     'gui',
     'utils',
     'kernel_downloader',
+    'data_loader',
 ]
 
 
