@@ -21,9 +21,11 @@ class Body(SpiceBase):
     parameters allow customising the exact settings used in the internal SPICE
     functions. Similarly, some methods (e.g. :func:`terminator_radec`) have parameters
     that are passed to SPICE functions which can almost always be left as their default
-    values.
+    values. See the
+    `SPICE documentation <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/subpnt_c.html#Detailed_Input>`_
+    for more details about possible parameter values. 
 
-    The `target` and `observer` names are passed to 
+    The `target` and `observer` names are passed to
     :func:`SpiceBase.standardise_body_name`, so a variety of formats are acceptable. For
     example `'jupiter'`, `'JUPITER'`, `' Jupiter '`, `'599'` and `599` will
     all resolve to `'JUPITER'`.
@@ -36,13 +38,14 @@ class Body(SpiceBase):
         utc: Time of observation. This can be provided in a variety of formats and is
             assumed to be UTC unless otherwise specified. The accepted formats are: any
             `string` datetime representation compatible with SPICE (e.g.
-            `'2000-12-31T23:59:59'` - see
-            https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/utc2et_c.html
-            for the acceptable string formats), a Python `datetime` object, or a `float`
-            representing the Modified Julian Date (MJD) of the observation.
+            `'2000-12-31T23:59:59'` - see the
+            `documentation of acceptable string formats <https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/C/cspice/utc2et_c.html>`_),
+            a Python `datetime` object, or a `float` representing the Modified Julian 
+            Date (MJD) of the observation. Alternatively, if `utc` is `None` (the
+            default), then the current time is used.
         observer: Name of observing body. Defaults to `'EARTH'`.
-        observer_frame: Observer reference frame.
-        illumination_source: Illumination source (e.g. the sun).
+        observer_frame: Observer reference frame. Defaults to `'J2000'`,
+        illumination_source: Illumination source. Defaults to `'SUN'`.
         aberration_correction: Aberration correction used to correct light travel time
             in SPICE.
         subpoint_method: Method used to calculate the sub-observer point in SPICE.
@@ -52,9 +55,9 @@ class Body(SpiceBase):
 
     def __init__(
         self,
-        target: str|int,
-        utc: str | datetime.datetime | float,
-        observer: str|int = 'EARTH',
+        target: str | int,
+        utc: str | datetime.datetime | float | None = None,
+        observer: str | int = 'EARTH',
         *,
         observer_frame: str = 'J2000',
         illumination_source: str = 'SUN',
@@ -111,22 +114,32 @@ class Body(SpiceBase):
         """Latitude of the sub-observer point on the target."""
         self.ring_radii: set[float]
         """
-        Set of ring raddii in km to plot around the target body's equator. Each radius
-        is plottted as a single line, so for a wide ring you may want to add both the
+        Set of ring radii in km to plot around the target body's equator. Each radius
+        is plotted as a single line, so for a wide ring you may want to add both the
         inner and outer edger of the ring. The radii are defined as the distance from
         the centre of the target body to the ring. For Saturn, the A, B and C rings from
         https://nssdc.gsfc.nasa.gov/planetary/factsheet/satringfact.html are included by
         default. For all other bodies, `ring_radii` is empty by default.
-        
-        See also :func:`ring_radec`.
+
+        Ring radii data from the 
+        `planetary factsheets <https://nssdc.gsfc.nasa.gov/planetary/planetfact.html>`_ 
+        can be loaded using :func:`data_loader.get_ring_radii`.
         
         Example usage: ::
 
             body.ring_radii.add(122340) # Add new ring radius to plot
             body.ring_radii.add(136780) # Add new ring radius to plot
+            body.ring_radii.update([66900, 74510]) # Add multiple radii to plot once
 
             body.ring_radii.remove(122340) # Remove a ring radius
             body.ring_radii.clear() # Remove all ring radii
+
+            # Add ring radii using data from planetary factsheets
+            ring_data = planetmapper.data_loader.get_ring_radii()['JUPITER']
+            body.ring_radii.update(ring_data['Main Ring'])
+            body.ring_radii.update(ring_data['Amalthea Ring'])
+        
+        See also :func:`ring_radec`.
         """
         self.coordinates_of_interest_lonlat: list[tuple[float, float]]
         """
@@ -151,14 +164,17 @@ class Body(SpiceBase):
         """
 
         # Process inputs
-        self.target = self.standardise_body_name(target)
         if isinstance(utc, float):
             utc = self.mjd2dtm(utc)
+        if utc is None:
+            utc = datetime.datetime.now(datetime.timezone.utc)
         if isinstance(utc, datetime.datetime):
             # convert input datetime to UTC, then to a string compatible with spice
-            utc = utc.astimezone(datetime.timezone.utc)
+            utc = utc.replace(tzinfo=datetime.timezone.utc)
             utc = utc.strftime(self._DEFAULT_DTM_FORMAT_STRING)
         self.utc = utc
+
+        self.target = self.standardise_body_name(target)
         self.observer = self.standardise_body_name(observer)
         self.observer_frame = observer_frame
         self.illumination_source = illumination_source
@@ -266,7 +282,7 @@ class Body(SpiceBase):
     def __repr__(self) -> str:
         return f'Body({self.target!r}, {self.utc!r})'
 
-    def create_other_body(self, other_target: str) -> 'Body':
+    def create_other_body(self, other_target: str|int) -> 'Body':
         """
         Create a :class:`Body` instance using identical parameters but just with a
         different target. For example, the `europa` body created here will have
@@ -297,15 +313,24 @@ class Body(SpiceBase):
             surface_method=self.surface_method,
         )
 
-    def add_other_bodies_of_interest(self, *other_targets: str):
+    def add_other_bodies_of_interest(self, *other_targets: str|int):
         """
         Add targets to the list of :attr:`other_bodies_of_interest` of interest to mark
         when plotting. The other targets are created using :func:`create_other_body`.
         For example, to add the Galilean moons as other targets to a Jupiter body,
         use ::
 
+            body = planetmapper.Body('Jupiter')
             body.add_other_bodies_of_interest('Io', 'Europa', 'Ganymede', 'Callisto')
 
+        Integer SPICE ID codes can also be provided, which can be used to simplify
+        adding multiple satellites to plots. ::
+
+            body = planetmapper.Body('Uranus')
+            body.add_other_bodies_of_interest(*range(701, 711))
+            # Uranus' satellites have ID codes 701, 702, 703 etc, so this adds 10 moons
+            # with a single function call 
+
         Args:
             *other_targets: Names of the other targets, passed to :class:`Body`
         """
@@ -551,17 +576,18 @@ class Body(SpiceBase):
     # Coordinate transformations km <-> radec
     def _get_km2radec_matrix_radians(self) -> np.ndarray:
         # Based on code in BodyXY._get_xy2radec_matrix_radians()
-        # TODO make this actually work
         if self._matrix_km2radec is None:
             r_km = self.r_eq
             r_radians = np.arcsin(r_km / self.target_distance)
             s = r_radians / r_km
             theta = -np.deg2rad(self.north_pole_angle())
+            direction_matrix = np.array([[-1, 0], [0, 1]])
             stretch_matrix = np.array(
-                [[-1 / np.abs(np.cos(self._target_dec_radians)), 0], [0, 1]]
+                [[1 / np.abs(np.cos(self._target_dec_radians)), 0], [0, 1]]
             )
             rotation_matrix = self._rotation_matrix_radians(theta)
-            transform_matrix_2x2 = s * np.matmul(rotation_matrix, stretch_matrix)
+            transform_matrix_2x2 = s * np.matmul(stretch_matrix, rotation_matrix)
+            transform_matrix_2x2 = np.matmul(transform_matrix_2x2, direction_matrix)
 
             v0 = np.array([0, 0])
             a0 = np.array([self._target_ra_radians, self._target_dec_radians])
@@ -587,10 +613,31 @@ class Body(SpiceBase):
         return v[0], v[1]
 
     def km2radec(self, km_x: float, km_y: float) -> tuple[float, float]:
-        # TODO docstring
+        """
+        Convert distance in target plane to RA/Dec sky coordinates for the observer.
+
+        Args:
+            km_x: Distance in target plane in km in the East-West direction.
+            km_y: Distance in target plane in km in the North-South direction.
+
+        Returns:
+            `(ra, dec)` tuple containing the RA/Dec coordinates of the point.
+        """
         return self._radian_pair2degrees(*self._km2radec_radians(km_x, km_y))
 
     def radec2km(self, ra: float, dec: float) -> tuple[float, float]:
+        """
+        Convert RA/Dec sky coordinates for the observer to distances in the target 
+        plane.
+
+        Args:
+            ra: Right ascension of point in the sky of the observer.
+            dec: Declination of point in the sky of the observer.
+
+        Returns:
+            `(km_x, km_y)` tuple containing distances in km in the target plane in the
+            East-West and North-South directions respectively.
+        """
         return self._radec2km_radians(*self._degree_pair2radians(ra, dec))
 
     def _get_matplotlib_radec2km_transform_radians(
@@ -605,7 +652,19 @@ class Body(SpiceBase):
     def matplotlib_radec2km_transform(
         self, ax: Axes | None = None
     ) -> matplotlib.transforms.Transform:
-        # TODO docstring
+        """
+        Get matplotlib transform which converts RA/Dec sky coordinates to target plane
+        distance coordinates.
+
+        Args:
+            ax: Optionally specify a matplotlib axis to return
+                `transform_radec2km + ax.transData`. This value can then be used in the
+                `transform` keyword argument of a Matplotlib function without any
+                further modification.
+
+        Returns:
+            Matplotlib transformation from `radec` to `km` coordinates.
+        """
         if self._mpl_transform_radec2km is None:
             transform_rad2deg = matplotlib.transforms.Affine2D().scale(np.deg2rad(1))
             self._mpl_transform_radec2km = (
@@ -619,7 +678,19 @@ class Body(SpiceBase):
     def matplotlib_km2radec_transform(
         self, ax: Axes | None = None
     ) -> matplotlib.transforms.Transform:
-        # TODO dosctring
+        """
+        Get matplotlib transform which converts target plane distance coordinates to
+        RA/Dec sky coordinates.
+
+        Args:
+            ax: Optionally specify a matplotlib axis to return
+                `transform_km2radec + ax.transData`. This value can then be used in the
+                `transform` keyword argument of a Matplotlib function without any
+                further modification.
+
+        Returns:
+            Matplotlib transformation from `km` to `radec` coordinates.
+        """
         if self._mpl_transform_km2radec is None:
             self._mpl_transform_km2radec = (
                 self.matplotlib_radec2km_transform().inverted()
@@ -648,7 +719,7 @@ class Body(SpiceBase):
     # Limb
     def _limb_targvec(
         self,
-        npts: int = 100,
+        npts: int = 360,
         close_loop: bool = True,
         method: str = 'TANGENT/ELLIPSOID',
         corloc: str = 'ELLIPSOID LIMB',
@@ -761,17 +832,24 @@ class Body(SpiceBase):
         )
         return np.rad2deg(phase), np.rad2deg(incdnc), np.rad2deg(emissn)
 
-    def _azimuth_angle_from_gie_radians(self, phase_radians: Numeric,incidence_radians:Numeric, emission_radians:Numeric) -> Numeric:
+    def _azimuth_angle_from_gie_radians(
+        self,
+        phase_radians: Numeric,
+        incidence_radians: Numeric,
+        emission_radians: Numeric,
+    ) -> Numeric:
         # Based on Henrik's code at:
         # https://github.com/JWSTGiantPlanets/NIRSPEC-Toolkit/blob/5e2e2cc/JWSTSolarSystemPointing.py#L204-L209
         a = np.cos(phase_radians) - np.cos(emission_radians) * np.cos(incidence_radians)
-        b = np.sqrt(1.0 - np.cos(emission_radians) ** 2) * np.sqrt(1.0 - np.cos(incidence_radians) ** 2)
+        b = np.sqrt(1.0 - np.cos(emission_radians) ** 2) * np.sqrt(
+            1.0 - np.cos(incidence_radians) ** 2
+        )
         azimuth_radians = np.pi - np.arccos(a / b)
         return azimuth_radians
 
     def azimuth_angle_from_lonlat(self, lon: float, lat: float) -> float:
         """
-        Calculate the azimuth angle of a longitude/latitude coordinate on the target 
+        Calculate the azimuth angle of a longitude/latitude coordinate on the target
         body.
 
         Args:
@@ -781,12 +859,16 @@ class Body(SpiceBase):
         Returns:
             Azimuth angle in degrees.
         """
-        azimuth_radians = self._azimuth_angle_from_gie_radians(*self._illumination_angles_from_targvec_radians(self.lonlat2targvec(lon, lat)))
+        azimuth_radians = self._azimuth_angle_from_gie_radians(
+            *self._illumination_angles_from_targvec_radians(
+                self.lonlat2targvec(lon, lat)
+            )
+        )
         return np.rad2deg(azimuth_radians)
 
     def terminator_radec(
         self,
-        npts: int = 100,
+        npts: int = 360,
         only_visible: bool = True,
         close_loop: bool = True,
         method: str = 'UMBRAL/TANGENT/ELLIPSOID',
@@ -883,7 +965,7 @@ class Body(SpiceBase):
         return lon_radec + lat_radec
 
     def visible_lon_grid_radec(
-        self, lons: list[float] | np.ndarray, npts: int = 50
+        self, lons: list[float] | np.ndarray, npts: int = 60
     ) -> list[tuple[np.ndarray, np.ndarray]]:
         """
         Calculates the RA/Dec coordinates for visible lines of constant longitude.
@@ -913,7 +995,7 @@ class Body(SpiceBase):
         return out
 
     def visible_lat_grid_radec(
-        self, lats: list[float] | np.ndarray, npts: int = 100
+        self, lats: list[float] | np.ndarray, npts: int = 120
     ) -> list[tuple[np.ndarray, np.ndarray]]:
         """
         Constant latitude version of :func:`visible_lon_grid_radec`. See also
@@ -1086,7 +1168,7 @@ class Body(SpiceBase):
     # Other
     def north_pole_angle(self) -> float:
         """
-        Calculate the angle of the north pole of the target body relative to the 
+        Calculate the angle of the north pole of the target body relative to the
         positive declination direction.
 
         Returns:
@@ -1150,6 +1232,7 @@ class Body(SpiceBase):
         transform: None | matplotlib.transforms.Transform,
         ax: Axes | None = None,
         color: str | tuple[float, float, float] = 'k',
+        label_poles: bool = True,
         **kwargs,
     ) -> Axes:
         """Plot generic wireframe representation of the observation"""
@@ -1190,25 +1273,26 @@ class Body(SpiceBase):
         ra_day, dec_day, ra_night, dec_night = self.limb_radec_by_illumination()
         ax.plot(ra_day, dec_day, color=color, transform=transform, **kwargs)
 
-        for lon, lat, s in self.get_poles_to_plot():
-            ra, dec = self.lonlat2radec(lon, lat)
-            ax.text(
-                ra,
-                dec,
-                s,
-                ha='center',
-                va='center',
-                size='small',
-                weight='bold',
-                color=color,
-                path_effects=[
-                    path_effects.Stroke(linewidth=3, foreground='w'),
-                    path_effects.Normal(),
-                ],
-                transform=transform,
-                clip_on=True,
-                **kwargs,
-            )
+        if label_poles:
+            for lon, lat, s in self.get_poles_to_plot():
+                ra, dec = self.lonlat2radec(lon, lat)
+                ax.text(
+                    ra,
+                    dec,
+                    s,
+                    ha='center',
+                    va='center',
+                    size='small',
+                    weight='bold',
+                    color=color,
+                    path_effects=[
+                        path_effects.Stroke(linewidth=3, foreground='w'),
+                        path_effects.Normal(),
+                    ],
+                    transform=transform,
+                    clip_on=True,
+                    **kwargs,
+                )
 
         for lon, lat in self.coordinates_of_interest_lonlat:
             if self.test_if_lonlat_visible(lon, lat):
@@ -1267,6 +1351,7 @@ class Body(SpiceBase):
         ax: Axes | None = None,
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
+        label_poles: bool = True,
         dms_ticks: bool = True,
         **kwargs,
     ) -> Axes:
@@ -1279,13 +1364,18 @@ class Body(SpiceBase):
                 `plt.gca()` to get the currently active axis.
             show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
+            label_poles: Toggle labelling the poles of the target body.
             dms_ticks: Toggle between showing ticks as degrees, minutes and seconds
                 (e.g. 12°34′56″) or decimal degrees (e.g. 12.582).
+            **kwargs: Additional arguments are passed to Matplotlib plotting functions
+                (useful for e.g. specifying `zorder`).
 
         Returns:
             The axis containing the plotted wireframe.
         """
-        ax = self._plot_wireframe(transform=None, ax=ax, color=color, **kwargs)
+        ax = self._plot_wireframe(
+            transform=None, ax=ax, color=color, label_poles=label_poles, **kwargs
+        )
 
         utils.format_radec_axes(ax, self.target_dec, dms_ticks)
 
@@ -1298,12 +1388,30 @@ class Body(SpiceBase):
         ax: Axes | None = None,
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
+        label_poles: bool = True,
         **kwargs,
     ) -> Axes:
-        # TODO docstring
+        """
+        Plot basic wireframe representation of the observation on a target centred
+        frame.
+
+        Args:
+            ax: Matplotlib axis to use for plotting. If `ax` is None (the default), uses
+                `plt.gca()` to get the currently active axis.
+            show: Toggle immediately showing the plotted figure with `plt.show()`.
+            color: Matplotlib color used for to plot the wireframe.
+            label_poles: Toggle labelling the poles of the target body.
+            **kwargs: Additional arguments are passed to Matplotlib plotting functions
+                (useful for e.g. specifying `zorder`).
+
+        Returns:
+            The axis containing the plotted wireframe.
+        """
 
         transform = self.matplotlib_radec2km_transform()
-        ax = self._plot_wireframe(transform=transform, ax=ax, color=color, **kwargs)
+        ax = self._plot_wireframe(
+            transform=transform, ax=ax, color=color, label_poles=label_poles, **kwargs
+        )
 
         ax.set_xlabel('Projected distance (km)')
         ax.set_ylabel('Projected distance (km)')
