@@ -19,6 +19,7 @@ import matplotlib.transforms
 import numpy as np
 import scipy.interpolate
 from matplotlib.axes import Axes
+from matplotlib.image import AxesImage
 from spiceypy.utils.exceptions import NotFoundError
 
 from .body import Body
@@ -190,7 +191,7 @@ class BodyXY(Body):
     def __init__(
         self,
         target: str,
-        utc: str | datetime.datetime | float,
+        utc: str | datetime.datetime | float | None = None,
         nx: int = 0,
         ny: int = 0,
         *,
@@ -301,11 +302,13 @@ class BodyXY(Body):
         r_radians = np.arcsin(r_km / self.target_distance)
         s = r_radians / self.get_r0()
         theta = self._get_rotation_radians()
+        direction_matrix = np.array([[-1, 0], [0, 1]])
         stretch_matrix = np.array(
-            [[-1 / np.abs(np.cos(self._target_dec_radians)), 0], [0, 1]]
+            [[1 / np.abs(np.cos(self._target_dec_radians)), 0], [0, 1]]
         )
         rotation_matrix = self._rotation_matrix_radians(theta)
-        transform_matrix_2x2 = s * np.matmul(rotation_matrix, stretch_matrix)
+        transform_matrix_2x2 = s * np.matmul(stretch_matrix, rotation_matrix)
+        transform_matrix_2x2 = np.matmul(transform_matrix_2x2, direction_matrix)
 
         v0 = np.array([self.get_x0(), self.get_y0()])
         a0 = np.array([self._target_ra_radians, self._target_dec_radians])
@@ -832,6 +835,8 @@ class BodyXY(Body):
         ax: Axes | None = None,
         show: bool = False,
         color: str | tuple[float, float, float] = 'k',
+        label_poles: bool = True,
+        **kwargs,
     ) -> Axes:
         """
         Plot basic wireframe representation of the observation using image pixel
@@ -842,6 +847,9 @@ class BodyXY(Body):
                 `plt.gca()` to get the currently active axis.
             show: Toggle immediately showing the plotted figure with `plt.show()`.
             color: Matplotlib color used for to plot the wireframe.
+            label_poles: Toggle labelling the poles of the target body.
+            **kwargs: Additional arguments are passed to Matplotlib plotting functions
+                (useful for e.g. specifying `zorder`).
 
 
         Returns:
@@ -849,7 +857,9 @@ class BodyXY(Body):
         """
         # Generate affine transformation from radec in degrees -> xy
         transform = self.matplotlib_radec2xy_transform()
-        ax = self._plot_wireframe(transform=transform, ax=ax, color=color)
+        ax = self._plot_wireframe(
+            transform=transform, ax=ax, color=color, label_poles=label_poles, **kwargs
+        )
 
         if self._test_if_img_size_valid():
             ax.set_xlim(-0.5, self._nx - 0.5)
@@ -863,7 +873,7 @@ class BodyXY(Body):
         return ax
 
     # Mapping
-    def map_img(self, img: np.ndarray, degree_interval: float = 1) -> np.ndarray:
+    def map_img(self, img: np.ndarray, degree_interval: float = 1, warn_nan:bool=True) -> np.ndarray:
         """
         Project an observed image onto a lon/lat grid.
 
@@ -876,6 +886,7 @@ class BodyXY(Body):
             degree_interval: Interval in degrees between the longitude/latitude points
                 in the mapped output. Passed to :func:`get_x_map` and :func:`get_y_map`
                 when generating the coordinates used for the projection.
+            warn_nan: Print warning if any values in `img` are NaN.
 
         Returns:
             Array containing cylindrical map of the values in `img` at each location on
@@ -884,6 +895,10 @@ class BodyXY(Body):
         """
         x_map = self.get_x_map(degree_interval)
         y_map = self.get_y_map(degree_interval)
+        if np.any(np.isnan(img)):
+            if warn_nan:
+                print('Warning, image contains NaN values which will be set to 0')
+            img = np.nan_to_num(img)
         interpolator = scipy.interpolate.RectBivariateSpline(
             np.arange(img.shape[0]), np.arange(img.shape[1]), img, kx=1, ky=1
         )
@@ -1105,16 +1120,44 @@ class BodyXY(Body):
             fig, ax = plt.subplots()
         backplane = self.get_backplane(name)
 
+        im = self.imshow_map(backplane.get_map(degree_interval), ax=ax)
+        plt.colorbar(im, label=backplane.description)
+        ax.set_title(self.get_description(multiline=True))
+        if show:
+            plt.show()
+        return ax
+
+    def imshow_map(
+        self, map_img: np.ndarray, ax: Axes | None = None, **kwargs
+    ) -> AxesImage:
+        """
+        Utility function to easily plot a mapped image using `plt.imshow` with
+        appropriate extents, axis labels etc.
+
+        This is equivalent to calling `ax.imshow(map_img, origin='lower', ...)` with
+        additional code to format the axis nicely.
+
+        Args:
+            map_img: Image to plot.
+            ax: Matplotlib axis to use for plotting. If `ax` is None (the default), then
+                a new figure and axis is created.
+            **kwargs: Passed to Matplotlib's `imshow` when plotting the backplane map.
+                For example, can be used to set the colormap of the plot using
+                `body.plot_backplane_map(..., cmap='Greys')`.
+
+        Returns:
+            Handle of plotted Matplotlib `AxesImage`.
+        """
+        if ax is None:
+            fig, ax = plt.subplots()
+
         if self.positive_longitude_direction == 'W':
             extent = [360, 0, -90, 90]
         else:
             extent = [0, 360, -90, 90]
 
-        im = ax.imshow(
-            backplane.get_map(degree_interval), origin='lower', extent=extent, **kwargs
-        )
-        plt.colorbar(im, label=backplane.description)
-        ax.set_title(self.get_description(multiline=True))
+        im = ax.imshow(map_img, origin='lower', extent=extent, **kwargs)
+
         ax.set_aspect(1, adjustable='box')
         ax.set_xlabel(f'Planetographic longitude ({self.positive_longitude_direction})')
         ax.set_ylabel('Planetographic latitude')
@@ -1127,10 +1170,7 @@ class BodyXY(Body):
         yt = np.arange(-90, 90.1, step)
         ax.set_yticks(yt)
         ax.set_yticklabels([f'{y:.0f}°' for y in yt])
-
-        if show:
-            plt.show()
-        return ax
+        return im
 
     # Backplane generatotrs
     def _test_if_img_size_valid(self) -> bool:
@@ -1269,7 +1309,7 @@ class BodyXY(Body):
         See also :func:`get_backplane_img`.
 
         Returns:
-            Array containing the planetographic longitude value of each pixel in the 
+            Array containing the planetographic longitude value of each pixel in the
             image. Points off the disc have a value of NaN.
         """
         return self._get_lonlat_img()[:, :, 0]
@@ -1291,7 +1331,7 @@ class BodyXY(Body):
         See also :func:`get_backplane_img`.
 
         Returns:
-            Array containing the planetographic latitude value of each pixel in the 
+            Array containing the planetographic latitude value of each pixel in the
             image. Points off the disc have a value of NaN.
         """
         return self._get_lonlat_img()[:, :, 1]
@@ -1315,7 +1355,6 @@ class BodyXY(Body):
         for y, x, targvec in self._enumerate_targvec_img(progress=True):
             out[y, x] = self._targvec2lonlat_centric(targvec)
         return out
-    
 
     @_cache_stable_result
     @progress_decorator
@@ -1594,16 +1633,18 @@ class BodyXY(Body):
             Array containing the azimuth angle value of each pixel in the image. Points
             off the disc have a value of NaN.
         """
-        phase_radians = self._get_illumination_gie_img()[:, :, 0]
-        incidence_radians= self._get_illumination_gie_img()[:, :, 1]
-        emission_radians = self._get_illumination_gie_img()[:, :, 2]
+        phase_radians = np.deg2rad(self._get_illumination_gie_img()[:, :, 0])
+        incidence_radians = np.deg2rad(self._get_illumination_gie_img()[:, :, 1])
+        emission_radians = np.deg2rad(self._get_illumination_gie_img()[:, :, 2])
         with warnings.catch_warnings():
             # TODO should we do this better?
             warnings.filterwarnings('ignore', 'divide by zero encountered in')
             warnings.filterwarnings('ignore', 'invalid value encountered in')
-            azimuth_radians = self._azimuth_angle_from_gie_radians(phase_radians, incidence_radians,emission_radians)
+            azimuth_radians = self._azimuth_angle_from_gie_radians(
+                phase_radians, incidence_radians, emission_radians
+            )
         return np.rad2deg(azimuth_radians)
-    
+
     @_cache_stable_result
     def get_azimuth_angle_map(self, degree_interval: float = 1) -> np.ndarray:
         """
@@ -1616,14 +1657,16 @@ class BodyXY(Body):
             Array containing cylindrical map of the azimuth angle value at each point
             on the target's surface.
         """
-        phase_radians = self._get_illumf_map(degree_interval)[:, :, 0]
-        incidence_radians= self._get_illumf_map(degree_interval)[:, :, 1]
-        emission_radians = self._get_illumf_map(degree_interval)[:, :, 2]
+        phase_radians = np.deg2rad(self._get_illumf_map(degree_interval)[:, :, 0])
+        incidence_radians = np.deg2rad(self._get_illumf_map(degree_interval)[:, :, 1])
+        emission_radians = np.deg2rad(self._get_illumf_map(degree_interval)[:, :, 2])
         with warnings.catch_warnings():
             # TODO should we do this better?
             warnings.filterwarnings('ignore', 'divide by zero encountered in')
             warnings.filterwarnings('ignore', 'invalid value encountered in')
-            azimuth_radians = self._azimuth_angle_from_gie_radians(phase_radians, incidence_radians,emission_radians)
+            azimuth_radians = self._azimuth_angle_from_gie_radians(
+                phase_radians, incidence_radians, emission_radians
+            )
         return np.rad2deg(azimuth_radians)
 
     @_cache_clearable_result
@@ -1752,7 +1795,7 @@ class BodyXY(Body):
         return self.calculate_doppler_factor(
             self.get_radial_velocity_map(degree_interval)
         )
-    
+
     # Default backplane registration
     def _register_default_backplanes(self) -> None:
         self.register_backplane(
